
This is a patch file against 0.2.2.

Change to directory g10-0.2.2 (or however you renamed it)
and give this command:

     zcat somepath/g10-0.2.3.diff.gz | patch -p1

It is a good idea to rename your current directory to g10-0.2.3 now.



Prereq: 0.2.2

diff -urN g10-0.2.2/VERSION g10-0.2.3/VERSION
--- g10-0.2.2/VERSION	Mon Feb  9 13:50:02 1998
+++ g10-0.2.3/VERSION	Mon Feb  9 18:01:08 1998
@@ -1 +1 @@
-0.2.2
+0.2.3
diff -urN g10-0.2.2/cipher/md.c g10-0.2.3/cipher/md.c
--- g10-0.2.2/cipher/md.c	Mon Feb  2 19:37:15 1998
+++ g10-0.2.3/cipher/md.c	Mon Feb  9 17:41:45 1998
@@ -28,6 +28,8 @@
 #include "errors.h"
 
 
+static FILE *dumpfp;
+
 /****************
  * Open a message digest handle for use with algorithm ALGO.
  * More algorithms may be added by md_enable(). The initial algorithm
@@ -38,6 +40,12 @@
 {
     MD_HANDLE hd;
 
+    if( !dumpfp )
+	dumpfp = fopen("md.out", "w");
+    if( !dumpfp )
+	BUG();
+    { int i; for(i=0; i < 16; i++ ) putc('\xff', dumpfp ); }
+
     hd = secure ? m_alloc_secure_clear( sizeof *hd )
 		: m_alloc_clear( sizeof *hd );
     if( algo )
@@ -70,6 +78,7 @@
 {
     MD_HANDLE b;
 
+    { int i; for(i=0; i < 16; i++ ) putc('\xee', dumpfp ); }
     b = m_is_secure(a)? m_alloc_secure( sizeof *b )
 		      : m_alloc( sizeof *b );
     memcpy( b, a, sizeof *a );
@@ -89,6 +98,10 @@
 void
 md_write( MD_HANDLE a, byte *inbuf, size_t inlen)
 {
+    if( a->bufcount && fwrite(a->buffer, a->bufcount, 1, dumpfp ) != 1 )
+	BUG();
+    if( inlen && fwrite(inbuf, inlen, 1, dumpfp ) != 1 )
+	BUG();
     if( a->use_rmd160 ) {
 	rmd160_write( &a->rmd160, a->buffer, a->bufcount );
 	rmd160_write( &a->rmd160, inbuf, inlen	);
@@ -111,6 +124,7 @@
 {
     if( a->bufcount )
 	md_write( a, NULL, 0 );
+    { int i; for(i=0; i < 16; i++ ) putc('\xcc', dumpfp ); }
     if( a->use_rmd160 ) {
 	byte *p;
 	rmd160_final( &a->rmd160 );
diff -urN g10-0.2.2/g10/Makefile.am g10-0.2.3/g10/Makefile.am
--- g10-0.2.2/g10/Makefile.am	Mon Feb  9 13:01:28 1998
+++ g10-0.2.3/g10/Makefile.am	Mon Feb  9 17:17:21 1998
@@ -1,7 +1,7 @@
 ## Process this file with automake to produce Makefile.in
 
 INCLUDES = -I$(top_srcdir)/include
-EXTRA_DIST = OPTIONS
+EXTRA_DIST = OPTIONS  pubring.g10
 needed_libs = ../cipher/libcipher.a ../mpi/libmpi.a ../util/libutil.a
 
 bin_PROGRAMS = g10 g10maint
diff -urN g10-0.2.2/g10/Makefile.in g10-0.2.3/g10/Makefile.in
--- g10-0.2.2/g10/Makefile.in	Mon Feb  9 16:08:43 1998
+++ g10-0.2.3/g10/Makefile.in	Mon Feb  9 18:04:46 1998
@@ -87,7 +87,7 @@
 VERSION = @VERSION@
 
 INCLUDES = -I$(top_srcdir)/include
-EXTRA_DIST = OPTIONS
+EXTRA_DIST = OPTIONS  pubring.g10
 needed_libs = ../cipher/libcipher.a ../mpi/libmpi.a ../util/libutil.a
 
 bin_PROGRAMS = g10 g10maint
@@ -466,14 +466,15 @@
 	../include/../cipher/elgamal.h filter.h ../include/errors.h \
 	keydb.h ../include/util.h trustdb.h ../include/ttyio.h \
 	../include/i18n.h
-plaintext.o: plaintext.c ../include/util.h ../include/types.h \
-	../include/errors.h ../include/mpi.h ../include/iobuf.h \
-	../include/memory.h options.h packet.h ../include/cipher.h \
-	../include/../cipher/md.h ../include/../cipher/rmd.h \
-	../include/../cipher/sha1.h ../include/../cipher/md5.h \
-	../include/../cipher/rsa.h ../include/../cipher/blowfish.h \
-	../include/../cipher/gost.h ../include/../cipher/elgamal.h \
-	filter.h ../include/ttyio.h main.h keydb.h
+plaintext.o plaintext.lo: plaintext.c ../config.h ../include/util.h \
+	../include/types.h ../include/errors.h ../include/mpi.h \
+	../include/iobuf.h ../include/memory.h options.h packet.h \
+	../include/cipher.h ../include/../cipher/md.h \
+	../include/../cipher/rmd.h ../include/../cipher/sha1.h \
+	../include/../cipher/md5.h ../include/../cipher/rsa.h \
+	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
+	../include/../cipher/elgamal.h filter.h ../include/ttyio.h \
+	main.h keydb.h
 pubkey-enc.o: pubkey-enc.c ../include/util.h ../include/types.h \
 	../include/errors.h ../include/mpi.h ../include/iobuf.h \
 	../include/memory.h packet.h ../include/cipher.h \
diff -urN g10-0.2.2/g10/parse-packet.c g10-0.2.3/g10/parse-packet.c
--- g10-0.2.2/g10/parse-packet.c	Wed Feb  4 10:36:21 1998
+++ g10-0.2.3/g10/parse-packet.c	Mon Feb  9 17:20:39 1998
@@ -714,7 +714,7 @@
     version = iobuf_get_noeof(inp); pktlen--;
     if( pkttype == PKT_PUBKEY_SUBCERT && version == '#' ) {
 	/* early versions of G10 use old comments packets; luckily all those
-	 * comments are are started by a hash */
+	 * comments are started by a hash */
 	if( list_mode ) {
 	    printf(":old comment packet: \"" );
 	    for( ; pktlen; pktlen-- ) {
@@ -829,8 +829,6 @@
     pktlen = 0;
 
     if( list_mode ) {
-	/* a value if 'c' is used by armor to indicate a faked packet
-	 * it should be considered as 't' */
 	printf(":literal data packet:\n"
 	       "\tmode %c, created %lu, name=\"",
 		    mode >= ' ' && mode <'z'? mode : '?',
diff -urN g10-0.2.2/g10/plaintext.c g10-0.2.3/g10/plaintext.c
--- g10-0.2.2/g10/plaintext.c	Fri Jan  9 13:18:50 1998
+++ g10-0.2.3/g10/plaintext.c	Mon Feb  9 17:31:54 1998
@@ -45,6 +45,10 @@
     FILE *fp = NULL;
     int rc = 0;
     int c;
+static FILE *abc;
+if( !abc )
+    abc=fopen("plaintext.out", "wb");
+if( !abc ) BUG();
 
     /* create the filename as C string */
     if( opt.outfile ) {
@@ -78,6 +82,7 @@
 		rc = G10ERR_READ_FILE;
 		goto leave;
 	    }
+	    putc( c, abc );
 	    if( mfx->md )
 		md_putc(mfx->md, c );
 	    if( putc( c, fp ) == EOF ) {
@@ -89,6 +94,7 @@
     }
     else {
 	while( (c = iobuf_get(pt->buf)) != -1 ) {
+	    putc( c, abc );
 	    if( mfx->md )
 		md_putc(mfx->md, c );
 	    if( putc( c, fp ) == EOF ) {
Binary files g10-0.2.2/g10/pubring.g10 and g10-0.2.3/g10/pubring.g10 differ
diff -urN g10-0.2.2/g10/sign.c g10-0.2.3/g10/sign.c
--- g10-0.2.2/g10/sign.c	Thu Feb  5 10:14:47 1998
+++ g10-0.2.3/g10/sign.c	Mon Feb  9 17:55:00 1998
@@ -144,7 +144,7 @@
     }
 
     /* prepare to calculate the MD over the input */
-    if( opt.textmode && opt.armor && !outfile )
+    if( opt.textmode && !outfile )
 	iobuf_push_filter( inp, text_filter, &tfx );
     mfx.md = md_open(DIGEST_ALGO_RMD160, 0);
     if( !multifile )
@@ -301,22 +301,36 @@
 
 
 
+/****************
+ * note: we do not count empty lines at the beginning
+ */
 static int
 write_dash_escaped( IOBUF inp, IOBUF out, MD_HANDLE md )
 {
     int c;
     int lastlf = 1;
+    int skip_empty = 1;
 
     while( (c = iobuf_get(inp)) != -1 ) {
 	/* Note: We don't escape "From " because the MUA should cope with it */
-	if( lastlf && c == '-' ) {
-	    iobuf_put( out, c );
-	    iobuf_put( out, ' ' );
+	if( lastlf ) {
+	    if( c == '-' ) {
+		iobuf_put( out, c );
+		iobuf_put( out, ' ' );
+		skip_empty = 0;
+	    }
+	    else if( skip_empty && c == '\r' )
+		skip_empty = 2;
+	    else
+		skip_empty = 0;
 	}
 
-	md_putc(md, c );
+	if( !skip_empty )
+	    md_putc(md, c );
 	iobuf_put( out, c );
 	lastlf = c == '\n';
+	if( skip_empty == 2 )
+	    skip_empty = lastlf ? 0 : 1;
     }
     return 0; /* fixme: add error handling */
 }
